"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fp_ts_1 = require("fp-ts");
var sprintf_js_1 = require("sprintf-js");
var $ = require("jquery");
var defaultValue = 0;
var defaultOptions = {
    format: '%d',
    min: -Infinity,
    max: Infinity
};
function parseNumber(value) {
    if (value) {
        var num = parseFloat(value);
        if (typeof num === 'number' && !isNaN(num)) {
            return fp_ts_1.option.some(num);
        }
    }
    return fp_ts_1.option.none;
}
function getOpts(node, opts) {
    return {
        format: fp_ts_1.option
            .fromNullable(node.getAttribute('data-format'))
            .getOrElse(function () { return opts.format ? opts.format : defaultOptions.format; }),
        min: fp_ts_1.option
            .fromNullable(node.getAttribute('data-min'))
            .chain(parseNumber)
            .getOrElse(function () { return opts.min ? opts.min : defaultOptions.min; }),
        max: fp_ts_1.option
            .of(node.getAttribute('data-max'))
            .chain(parseNumber)
            .getOrElse(function () { return opts.max ? opts.max : defaultOptions.max; }),
    };
}
var BootstrapNumberSpinner = /** @class */ (function () {
    function BootstrapNumberSpinner(inputElement, opts) {
        this._value = defaultValue;
        this._inputElement = inputElement;
        this.options = getOpts(inputElement, opts ? opts : {});
        var that = this;
        var $spinner = $(this._inputElement);
        var $group = $spinner.closest('.input-group');
        $('[data-incr]', $group).each(function (i, btn) {
            var $btn = $(btn);
            var incr = parseFloat($btn.data('incr'));
            $btn.click(function () {
                that.value += incr;
                that.notify();
            });
        });
        $spinner
            .focus(function () {
            that._inputElement.value = that._value.toString();
        })
            .keypress(function (evt) {
            var k = evt.keyCode || evt.which;
            if (k === 13) {
                that.read();
                evt.preventDefault();
            }
        })
            .change(function (evt) {
            evt.stopPropagation();
            evt.stopImmediatePropagation();
            that.read();
        });
        // initial formatting
        that.read();
    }
    BootstrapNumberSpinner.prototype.limit = function (num) {
        return Math.min(Math.max(num, this.options.min), this.options.max);
    };
    BootstrapNumberSpinner.prototype.write = function () {
        this._inputElement.value = sprintf_js_1.sprintf(this.options.format, this._value);
    };
    BootstrapNumberSpinner.prototype.notify = function () {
        var event = new Event('change.bs.spinner');
        this._inputElement.dispatchEvent(event);
    };
    Object.defineProperty(BootstrapNumberSpinner.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (v) {
            this._value = this.limit(v);
            this.write();
        },
        enumerable: true,
        configurable: true
    });
    BootstrapNumberSpinner.prototype.read = function () {
        console.log("reading " + parseNumber(this._inputElement.value));
        this.value = parseNumber(this._inputElement.value).getOrElseValue(this._value);
        this.notify();
    };
    return BootstrapNumberSpinner;
}());
exports.BootstrapNumberSpinner = BootstrapNumberSpinner;
/*
  $.fn.bsSpinner = function(opts) {
    var spinner = this.data('spinner');
    if (spinner === undefined) {
      spinner = createSpinner.call(this, opts);
      this.data('spinner', spinner);
    }
    return this;
  };

  _.each($('.spinner'), function(node) {
    $(node).bsSpinner();
  });
*/
//# sourceMappingURL=bootstrap-number-spinner.js.map